@@ -2,7 +2,7 @@ from pytpp.attributes._helper import IterableMeta, Attribute
 
 
 class AgentCertificateBaseAttributes(metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Agent Certificate Base"
     certificate_scanner_capi = Attribute('Certificate Scanner CAPI')
     certificate_scanner_map = Attribute('Certificate Scanner Map')
     certificate_scanner_path = Attribute('Certificate Scanner Path')
