@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class ApertureConfigurationAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Aperture Configuration"
     applies_to = Attribute('Applies To')
     feedback_url = Attribute('Feedback Url')
     help_text = Attribute('Help Text')
