@@ -3,6 +3,6 @@ from pytpp.attributes.certificate_trust_store_base import CertificateTrustStoreB
 
 
 class BlueCoatSSLVATrustStoreAttributes(CertificateTrustStoreBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "BlueCoat SSLVA Trust Store"
     create_lists = Attribute('Create Lists')
     key_store = Attribute('Key Store')
