@@ -3,4 +3,4 @@ from pytpp.attributes.service_module import ServiceModuleAttributes
 
 
 class ClientGroupMonitorAttributes(ServiceModuleAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "ClientGroup Monitor"
