@@ -3,7 +3,7 @@ from pytpp.attributes.code_signing_environment_template_base import CodeSigningE
 
 
 class CodeSigningAppleEnvironmentTemplateAttributes(CodeSigningEnvironmentTemplateBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Code Signing Apple Environment Template"
     cn_pattern = Attribute('CN Pattern', min_version='21.2')
     certificate_authority = Attribute('Certificate Authority', min_version='22.1')
     certificate_container_dn = Attribute('Certificate Container DN', min_version='21.2')
