@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_trust_store_base import CertificateTrustStoreB
 
 
 class DataPowerTrustStoreAttributes(CertificateTrustStoreBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "DataPower Trust Store"
     application_domain = Attribute('Application Domain', min_version='20.3')
     crl_distribution_points_handling = Attribute('CRL Distribution Points Handling', min_version='20.3')
     certificate_validation_mode = Attribute('Certificate Validation Mode', min_version='20.3')
