@@ -3,7 +3,7 @@ from pytpp.attributes.branch_base import BranchBaseAttributes
 
 
 class DiscoveryRootAttributes(BranchBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Discovery Root"
     address_range = Attribute('Address Range')
     dsn = Attribute('DSN')
     driver_name = Attribute('Driver Name')
