@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class F5LTMAdvancedAttributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "F5 LTM Advanced"
     advanced_settings_bundle_name = Attribute('Advanced Settings Bundle Name')
     advertised_ca = Attribute('Advertised CA')
     archive_location = Attribute('Archive Location')
