@@ -3,4 +3,4 @@ from pytpp.attributes.credential_base import CredentialBaseAttributes
 
 
 class GoogleCredentialAttributes(CredentialBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Google Credential"
