@@ -3,7 +3,7 @@ from pytpp.attributes.identity_driver import IdentityDriverAttributes
 
 
 class LDAPIdentityDriverAttributes(IdentityDriverAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "LDAP Identity Driver"
     ambiguous_name_resolution = Attribute('Ambiguous Name Resolution')
     base_dn = Attribute('Base DN')
     configuration = Attribute('Configuration')
