@@ -3,7 +3,7 @@ from pytpp.attributes.log_channel import LogChannelAttributes
 
 
 class LogSplunkAttributes(LogChannelAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Log Splunk"
     credential = Attribute('Credential')
     host = Attribute('Host')
     index = Attribute('Index')
