@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class NetScalerAttributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "NetScaler"
     certificate_file = Attribute('Certificate File')
     chain_cert = Attribute('Chain Cert')
     file_validation_disabled = Attribute('File Validation Disabled')
