@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class OpenSSLCAAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "OpenSSL CA"
     certificate_directory = Attribute('Certificate Directory')
     certificate_file = Attribute('Certificate File')
     configuration_file = Attribute('Configuration File')
