@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class PersonAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Person"
     full_name = Attribute('Full Name')
     given_name = Attribute('Given Name')
     group_membership = Attribute('Group Membership')
