@@ -4,5 +4,5 @@ from pytpp.attributes.validation_base import ValidationBaseAttributes
 
 
 class SSHServerKeyAttributes(SSHKeyAttributes, ValidationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "SSH Server Key"
     network_validation_disabled = Attribute('Network Validation Disabled')
