@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class TrustAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Trust"
     allow_from = Attribute('Allow From', min_version='19.3')
     allowed_algorithm = Attribute('Allowed Algorithm', min_version='19.3')
     allowed_command = Attribute('Allowed Command', min_version='19.3')
