@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class TrustwaveCAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Trustwave CA"
     interval = Attribute('Interval')
     reseller_id = Attribute('Reseller ID')
     retrieval_period = Attribute('Retrieval Period')
