@@ -3,4 +3,4 @@ from pytpp.attributes.client_group_base import ClientGroupBaseAttributes
 
 
 class UntrustedClientGroupAttributes(ClientGroupBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Untrusted Client Group"
