@@ -4,7 +4,7 @@ from pytpp.attributes.x509_certificate_validation import X509CertificateValidati
 
 
 class X509CertificateAttributes(X509CertificateBaseAttributes, X509CertificateValidationAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "X509 Certificate"
     acme_account_dn = Attribute('ACME Account DN', min_version='17.2')
     application_group_dn = Attribute('Application Group DN', min_version='19.4')
     geotrusttrueflex_ca_emails = Attribute('GeotrustTrueFlex CA:Emails', min_version='15.3')
